summaryrefslogtreecommitdiff
path: root/security/landlock/fs.h
diff options
context:
space:
mode:
Diffstat (limited to 'security/landlock/fs.h')
-rw-r--r--security/landlock/fs.h15
1 files changed, 9 insertions, 6 deletions
diff --git a/security/landlock/fs.h b/security/landlock/fs.h
index d445f411c26a..b29972eb9224 100644
--- a/security/landlock/fs.h
+++ b/security/landlock/fs.h
@@ -1,9 +1,10 @@
/* SPDX-License-Identifier: GPL-2.0-only */
/*
- * Landlock LSM - Filesystem management and hooks
+ * Landlock - Filesystem management and hooks
*
* Copyright © 2017-2020 Mickaël Salaün <mic@digikod.net>
* Copyright © 2018-2020 ANSSI
+ * Copyright © 2024-2025 Microsoft Corporation
*/
#ifndef _SECURITY_LANDLOCK_FS_H
@@ -14,6 +15,7 @@
#include <linux/rcupdate.h>
#include "access.h"
+#include "cred.h"
#include "ruleset.h"
#include "setup.h"
@@ -54,12 +56,13 @@ struct landlock_file_security {
*/
access_mask_t allowed_access;
/**
* @fown_domain: Domain of the task that set the PID that may receive a
* signal e.g., SIGURG when writing MSG_OOB to the related socket.
* This pointer is protected by the related file->f_owner->lock, as for
* fown_struct's members: pid, uid, and euid.
*/
- struct landlock_ruleset *fown_domain;
+ struct landlock_cred_security fown_subject;
};
/**
@@ -54,12 +56,13 @@ struct landlock_file_security {
access_mask_t allowed_access;
/**
- * @fown_domain: Domain of the task that set the PID that may receive a
- * signal e.g., SIGURG when writing MSG_OOB to the related socket.
- * This pointer is protected by the related file->f_owner->lock, as for
- * fown_struct's members: pid, uid, and euid.
+ * @fown_subject: Landlock credential of the task that set the PID that
+ * may receive a signal e.g., SIGURG when writing MSG_OOB to the
+ * related socket. This pointer is protected by the related
+ * file->f_owner->lock, as for fown_struct's members: pid, uid, and
+ * euid.
*/